@@ -332,6 +332,15 @@ using the configure script.
 
 #endif
 
+#if 0
+#define NTL_DISABLE_LL_ASM
+
+/* Explicitly disables us of inline assembly as a replacement
+ * for long lobg arithmetic.
+ */
+
+#endif
+
 
 #if 0
 #define NTL_MAXIMIZE_SP_NBITS
@@ -499,7 +508,7 @@ using the configure script.
 
 
 
-#if 1
+#if 0
 #define NTL_TBL_REM
 
 /*
@@ -620,6 +629,4 @@ using the configure script.
 
 
 
-
-
 #endif
